==> ros-kinetic-plotjuggler_0.17.0.orig.tar.gz: ros-kinetic-plotjuggler-0.17.0/plotter_gui/tabbedplotwidget.h <==
#ifndef TABBEDPLOTWIDGET_H
#define TABBEDPLOTWIDGET_H

#include <QWidget>
#include <QMainWindow>
#include <QTableWidget>
#include "plotmatrix.h"

namespace Ui {
class TabbedPlotWidget;
}


class TabbedPlotWidget : public QWidget
{
    Q_OBJECT

public:
    typedef struct{} MainWindowArea;

    explicit TabbedPlotWidget(QMainWindow *main_window,
                              PlotMatrix *first_tab,
                              PlotDataMap *mapped_data,
                              QMainWindow *parent );

    void setSiblingsList( const std::map<QString,TabbedPlotWidget*>& other_tabbed_widgets );

    PlotMatrix* currentTab();

    QTabWidget* tabWidget();

    void addTab(PlotMatrix *tab = NULL);

    QDomElement xmlSaveState(QDomDocument &doc) const;
    bool xmlLoadState(QDomElement &tabbed_area);

    ~TabbedPlotWidget();

public slots:

    void setStreamingMode(bool streaming_mode);

private slots:

    void on_renameCurrentTab();

    void on_savePlotsToFile();

    void on_pushAddColumn_pressed();

    void on_pushVerticalResize_pressed();

    void on_pushHorizontalResize_pressed();

    void on_pushAddRow_pressed();

    void on_addTabButton_pressed();

    void on_pushRemoveEmpty_pressed();

    void on_tabWidget_currentChanged(int index);

    void on_tabWidget_tabCloseRequested(int index);

    void on_buttonLinkHorizontalScale_toggled(bool checked);

    void on_requestTabMovement(const QString &destination_name);

    void on_moveTabIntoNewWindow();

    void on_pushButtonShowLabel_toggled(bool checked);

private:
    Ui::TabbedPlotWidget *ui;

    QAction* _action_renameTab;
    QAction* _action_savePlots;

    QMenu* _tab_menu;

    PlotDataMap *_mapped_data;

    bool _horizontal_link;

    QString _parent_type;

    std::map<QString,TabbedPlotWidget*> _other_siblings;

protected:
    virtual bool eventFilter(QObject *obj, QEvent *event);

signals:
    void created();
    void undoableChangeHappened();
    void matrixAdded( PlotMatrix * );
    void sendTabToNewWindow(PlotMatrix *);
};

#endif // TABBEDPLOTWIDGET_H

==> ros-kinetic-plotjuggler_1.6.2.orig.tar.gz: ros-kinetic-plotjuggler-1.6.2/plotter_gui/tabbedplotwidget.h <==
#ifndef TABBEDPLOTWIDGET_H
#define TABBEDPLOTWIDGET_H

#include <QWidget>
#include <QMainWindow>
#include <QTableWidget>
#include "plotmatrix.h"

namespace Ui {
class TabbedPlotWidget;
}


class TabbedPlotWidget : public QWidget
{
    Q_OBJECT

public:
    typedef struct{} MainWindowArea;

    explicit TabbedPlotWidget(QString name,
                              QMainWindow *main_window,
                              PlotMatrix* first_tab,
                              PlotDataMap &mapped_data,
                              QMainWindow *parent );

    PlotMatrix* currentTab();

    QTabWidget* tabWidget();

    void addTab(PlotMatrix *tab = NULL);

    QDomElement xmlSaveState(QDomDocument &doc) const;
    bool xmlLoadState(QDomElement &tabbed_area);

    ~TabbedPlotWidget();

    QString name() const { return _name; }

    static const std::map<QString,TabbedPlotWidget*>& instances();

    static TabbedPlotWidget *instance(const QString& key);

    void setControlsVisible(bool visible);

public slots:

    void setStreamingMode(bool streaming_mode);

private slots:

    void on_renameCurrentTab();

    void on_savePlotsToFile();

    void on_pushAddColumn_pressed();

    void on_pushVerticalResize_pressed();

    void on_pushHorizontalResize_pressed();

    void on_pushAddRow_pressed();

    void on_addTabButton_pressed();

    void on_pushRemoveEmpty_pressed();

    void on_tabWidget_currentChanged(int index);

    void on_tabWidget_tabCloseRequested(int index);

    void on_buttonLinkHorizontalScale_toggled(bool checked);

    void on_requestTabMovement(const QString &destination_name);

    void on_moveTabIntoNewWindow();

    void on_pushButtonShowLabel_toggled(bool checked);

private:
    Ui::TabbedPlotWidget *ui;

    QAction* _action_renameTab;
    QAction* _action_savePlots;

    QMenu* _tab_menu;

    const QString _name;

    PlotDataMap& _mapped_data;

    bool _horizontal_link;

    QString _parent_type;

    virtual void closeEvent(QCloseEvent *event) override;

protected:

    virtual bool eventFilter(QObject *obj, QEvent *event);

    static std::map<QString,TabbedPlotWidget*> _instances;

signals:
    void created();
    void undoableChangeHappened();
    void matrixAdded( PlotMatrix * );
    void sendTabToNewWindow(PlotMatrix *);
};

#endif // TABBEDPLOTWIDGET_H
